@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 1999-2001 by Jonathan Naylor G4KLX
+ *   Copyright (C) 1999-2004 by Jonathan Naylor G4KLX
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -48,17 +48,15 @@ struct User_Struct User_Data = {
 	}
 };
 
-static char About_Text[] = "baken v0.5\n"
+static char About_Text[] = "baken v0.5.2\n"
 	"A GTK based Beacon Display Program\n"
-	"19 September 2001\n"
-	"Written by Jonathan Naylor  G4KLX/HB9DRD\n"
-	"<g4klx@g4klx.demon.co.uk>";
+	"19 March 2004\n"
+	"Written by Jonathan Naylor  G4KLX\n";
 
 GtkWidget *MainMap;
 
 static GtkWidget *MainWindow;
 
-static void Exit_Box(GtkWidget *, gpointer);
 static void ExitCb(GtkWidget *, gpointer);
 static void AboutCb(GtkWidget *, gpointer);
 
@@ -78,11 +76,15 @@ static GtkItemFactoryEntry Menu_Items[] = {
 	{"/_File",                      NULL,      NULL,     0, "<Branch>"},
 	{"/File/New...",		NULL,	   ChooseCb, 0, NULL},
 	{"/File/sep",			NULL,	   NULL,     0, "<Separator>"},
-	{"/File/List",                  NULL,      ListCb,   0, NULL},
+	{"/File/List",                  NULL,      NULL,     0, "<Branch>"},
+	{"/File/List/By Frequency",     NULL,      ListCb,   LIST_FREQUENCY, NULL},
+	{"/File/List/By Distance",      NULL,      ListCb,   LIST_DISTANCE,  NULL},
+	{"/File/List/By Bearing",       NULL,      ListCb,   LIST_BEARING,   NULL},
+	{"/File/sep",			NULL,	   NULL,     0, "<Separator>"},
 	{"/File/Distance...",		NULL,	   DistCb,   0, NULL},
 	{"/File/Reflection...",		NULL,	   ReflCb,   0, NULL},
 	{"/File/sep",                   NULL,      NULL,     0, "<Separator>"},
-	{"/File/Exit",                  NULL,      Exit_Box, 0, NULL},
+	{"/File/Exit",                  NULL,      ExitCb,   0, NULL},
 	{"/_Edit",                      NULL,      NULL,     0, "<Branch>"},
 	{"/Edit/User...",               NULL,      EditCb,   0, NULL},
 	{"/_Colours",                   NULL,      NULL,     0, "<Branch>"},
@@ -333,11 +335,6 @@ static void NoCb(GtkWidget *widget, GtkWidget *window)
 		(*Question_No)();
 }
 
-static void Exit_Box(GtkWidget *widget, gpointer data)
-{
-	General_Box("Exit Baken", "Leave Baken ?", EXIT_BOX);
-}
-
 static void ExitCb(GtkWidget *widget, gpointer data)
 {
 	Write_User_Data();
